@@ -136,6 +136,8 @@ describe 'glance::api' do
             'delayed_delete',
             'scrub_time',
             'image_cache_dir',
+            'image_cache_stall_time',
+            'image_cache_max_size',
             'node_staging_uri',
             'image_member_quota',
             'enable_v1_api',
@@ -170,6 +172,7 @@ describe 'glance::api' do
           [
             'registry_host',
             'registry_port',
+            'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
           ].each do |config|
@@ -288,6 +291,16 @@ describe 'glance::api' do
       )}
     end
 
+    describe 'setting max_request_body_size' do
+      let :params do
+        default_params.merge({:max_request_body_size => '102400' })
+      end
+
+      it { is_expected.to contain_oslo__middleware('glance_api_config').with(
+        :max_request_body_size => '102400',
+      )}
+    end
+
     describe 'with ssl options' do
       let :params do
         default_params.merge({
