@@ -6,11 +6,18 @@ describe 'glance::db::sync' do
 
     it 'runs glance-manage db_sync' do
       is_expected.to contain_exec('glance-manage db_sync').with(
-        :command     => 'glance-manage --config-file /etc/glance/glance-registry.conf db_sync',
+        :command     => 'glance-manage  db_sync',
         :path        => '/usr/bin',
         :user        => 'glance',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[glance::install::end]',
+                         'Anchor[glance::config::end]',
+                         'Anchor[glance::dbsync::begin]'],
+        :notify      => 'Anchor[glance::dbsync::end]',
+        :tag         => 'openstack-db',
       )
     end
 
@@ -26,7 +33,14 @@ describe 'glance::db::sync' do
         :path        => '/usr/bin',
         :user        => 'glance',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[glance::install::end]',
+                         'Anchor[glance::config::end]',
+                         'Anchor[glance::dbsync::begin]'],
+        :notify      => 'Anchor[glance::dbsync::end]',
+        :tag         => 'openstack-db',
       )
       }
     end
